@@ -31,8 +31,6 @@ our @EXPORT = qw(
     getLinesCount
     compareVersion
     canRun
-    canRead
-    canLoad
     hex2char
     hex2dec
     dec2hex
@@ -53,7 +51,6 @@ my $nowhere = $OSNAME eq 'MSWin32' ? 'nul' : '/dev/null';
 # Anonymous function called in forbidden scalar context
 if ($OSNAME ne 'MSWin32') {
     memoize('canRun');
-    memoize('canRead');
 }
 
 sub getFormatedLocalTime {
@@ -362,18 +359,6 @@ sub canRun {
         scalar(which($binary)); # executable name
 }
 
-sub canRead {
-    my ($file) = @_;
-
-    return -f $file;
-}
-
-sub canLoad {
-    my ($module) = @_;
-
-    return $module->require();
-}
-
 sub hex2char {
     my ($value) = @_;
 
